==> apache-shenyu-2.6.0-src.zip: apache-shenyu-2.6.0-src/shenyu-sync-data-center/shenyu-sync-data-websocket/src/main/java/org/apache/shenyu/plugin/sync/data/websocket/handler/ProxySelectorDataHandler.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shenyu.plugin.sync.data.websocket.handler;

import org.apache.shenyu.common.dto.ProxySelectorData;
import org.apache.shenyu.common.utils.GsonUtils;
import org.apache.shenyu.sync.data.api.ProxySelectorDataSubscriber;

import java.util.List;
import java.util.Optional;

/**
 * ProxySelectorDataHandler.
 */
public class ProxySelectorDataHandler extends AbstractDataHandler<ProxySelectorData> {

    private final List<ProxySelectorDataSubscriber> proxySelectorDataSubscribers;

    public ProxySelectorDataHandler(final List<ProxySelectorDataSubscriber> proxySelectorDataSubscribers) {
        this.proxySelectorDataSubscribers = proxySelectorDataSubscribers;
    }

    @Override
    protected List<ProxySelectorData> convert(final String json) {
        return GsonUtils.getInstance().fromList(json, ProxySelectorData.class);
    }

    @Override
    protected void doRefresh(final List<ProxySelectorData> dataList) {
        proxySelectorDataSubscribers.forEach(ProxySelectorDataSubscriber::refresh);
        doUpdate(dataList);
    }

    @Override
    protected void doUpdate(final List<ProxySelectorData> dataList) {
        dataList.forEach(data -> {
            proxySelectorDataSubscribers.forEach(p -> {
                p.onSubscribe(data);
            });
        });
    }

    @Override
    protected void doDelete(final List<ProxySelectorData> dataList) {
        dataList.forEach(proxySelectorData -> {
            Optional.ofNullable(proxySelectorData)
                    .ifPresent(data -> proxySelectorDataSubscribers.forEach(e -> e.unSubscribe(proxySelectorData)));
        });
    }
}

==> apache-shenyu-2.7.0.2-src.zip: apache-shenyu-2.7.0.2-src/shenyu-sync-data-center/shenyu-sync-data-websocket/src/main/java/org/apache/shenyu/plugin/sync/data/websocket/handler/ProxySelectorDataHandler.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shenyu.plugin.sync.data.websocket.handler;

import org.apache.shenyu.common.dto.ProxySelectorData;
import org.apache.shenyu.common.utils.GsonUtils;
import org.apache.shenyu.sync.data.api.ProxySelectorDataSubscriber;

import java.util.List;
import java.util.Optional;

/**
 * ProxySelectorDataHandler.
 */
public class ProxySelectorDataHandler extends AbstractDataHandler<ProxySelectorData> {

    private final List<ProxySelectorDataSubscriber> proxySelectorDataSubscribers;

    public ProxySelectorDataHandler(final List<ProxySelectorDataSubscriber> proxySelectorDataSubscribers) {
        this.proxySelectorDataSubscribers = proxySelectorDataSubscribers;
    }

    @Override
    protected List<ProxySelectorData> convert(final String json) {
        return GsonUtils.getInstance().fromList(json, ProxySelectorData.class);
    }

    @Override
    protected void doRefresh(final List<ProxySelectorData> dataList) {
        proxySelectorDataSubscribers.forEach(ProxySelectorDataSubscriber::refresh);
        doUpdate(dataList);
    }

    @Override
    protected void doUpdate(final List<ProxySelectorData> dataList) {
        dataList.forEach(data -> proxySelectorDataSubscribers.forEach(p -> p.onSubscribe(data)));
    }

    @Override
    protected void doDelete(final List<ProxySelectorData> dataList) {
        dataList.forEach(proxySelectorData -> Optional.ofNullable(proxySelectorData)
                .ifPresent(data -> proxySelectorDataSubscribers.forEach(e -> e.unSubscribe(proxySelectorData))));
    }
}
